/**
 * @since 1.0.0
 */
import { type BatchExecuteStatementCommandInput, type BatchExecuteStatementCommandOutput, type BatchGetItemCommandInput, type BatchGetItemCommandOutput, type BatchWriteItemCommandInput, type BatchWriteItemCommandOutput, type CreateBackupCommandInput, type CreateBackupCommandOutput, type CreateGlobalTableCommandInput, type CreateGlobalTableCommandOutput, type CreateTableCommandInput, type CreateTableCommandOutput, type DeleteBackupCommandInput, type DeleteBackupCommandOutput, type DeleteItemCommandInput, type DeleteItemCommandOutput, type DeleteResourcePolicyCommandInput, type DeleteResourcePolicyCommandOutput, type DeleteTableCommandInput, type DeleteTableCommandOutput, type DescribeBackupCommandInput, type DescribeBackupCommandOutput, type DescribeContinuousBackupsCommandInput, type DescribeContinuousBackupsCommandOutput, type DescribeContributorInsightsCommandInput, type DescribeContributorInsightsCommandOutput, type DescribeEndpointsCommandInput, type DescribeEndpointsCommandOutput, type DescribeExportCommandInput, type DescribeExportCommandOutput, type DescribeGlobalTableCommandInput, type DescribeGlobalTableCommandOutput, type DescribeGlobalTableSettingsCommandInput, type DescribeGlobalTableSettingsCommandOutput, type DescribeImportCommandInput, type DescribeImportCommandOutput, type DescribeKinesisStreamingDestinationCommandInput, type DescribeKinesisStreamingDestinationCommandOutput, type DescribeLimitsCommandInput, type DescribeLimitsCommandOutput, type DescribeTableCommandInput, type DescribeTableCommandOutput, type DescribeTableReplicaAutoScalingCommandInput, type DescribeTableReplicaAutoScalingCommandOutput, type DescribeTimeToLiveCommandInput, type DescribeTimeToLiveCommandOutput, type DisableKinesisStreamingDestinationCommandInput, type DisableKinesisStreamingDestinationCommandOutput, type EnableKinesisStreamingDestinationCommandInput, type EnableKinesisStreamingDestinationCommandOutput, type ExecuteStatementCommandInput, type ExecuteStatementCommandOutput, type ExecuteTransactionCommandInput, type ExecuteTransactionCommandOutput, type ExportTableToPointInTimeCommandInput, type ExportTableToPointInTimeCommandOutput, type GetItemCommandInput, type GetItemCommandOutput, type GetResourcePolicyCommandInput, type GetResourcePolicyCommandOutput, type ImportTableCommandInput, type ImportTableCommandOutput, type ListBackupsCommandInput, type ListBackupsCommandOutput, type ListContributorInsightsCommandInput, type ListContributorInsightsCommandOutput, type ListExportsCommandInput, type ListExportsCommandOutput, type ListGlobalTablesCommandInput, type ListGlobalTablesCommandOutput, type ListImportsCommandInput, type ListImportsCommandOutput, type ListTablesCommandInput, type ListTablesCommandOutput, type ListTagsOfResourceCommandInput, type ListTagsOfResourceCommandOutput, type PutItemCommandInput, type PutItemCommandOutput, type PutResourcePolicyCommandInput, type PutResourcePolicyCommandOutput, type QueryCommandInput, type QueryCommandOutput, type RestoreTableFromBackupCommandInput, type RestoreTableFromBackupCommandOutput, type RestoreTableToPointInTimeCommandInput, type RestoreTableToPointInTimeCommandOutput, type ScanCommandInput, type ScanCommandOutput, type TagResourceCommandInput, type TagResourceCommandOutput, type TransactGetItemsCommandInput, type TransactGetItemsCommandOutput, type TransactWriteItemsCommandInput, type TransactWriteItemsCommandOutput, type UntagResourceCommandInput, type UntagResourceCommandOutput, type UpdateContinuousBackupsCommandInput, type UpdateContinuousBackupsCommandOutput, type UpdateContributorInsightsCommandInput, type UpdateContributorInsightsCommandOutput, type UpdateGlobalTableCommandInput, type UpdateGlobalTableCommandOutput, type UpdateGlobalTableSettingsCommandInput, type UpdateGlobalTableSettingsCommandOutput, type UpdateItemCommandInput, type UpdateItemCommandOutput, type UpdateKinesisStreamingDestinationCommandInput, type UpdateKinesisStreamingDestinationCommandOutput, type UpdateTableCommandInput, type UpdateTableCommandOutput, type UpdateTableReplicaAutoScalingCommandInput, type UpdateTableReplicaAutoScalingCommandOutput, type UpdateTimeToLiveCommandInput, type UpdateTimeToLiveCommandOutput } from "@aws-sdk/client-dynamodb";
import { type HttpHandlerOptions as __HttpHandlerOptions } from "@aws-sdk/types";
import { Effect, Layer } from "effect";
import { DynamoDBClientInstance } from "./DynamoDBClientInstance";
import { BackupInUseError, BackupNotFoundError, ConditionalCheckFailedError, ContinuousBackupsUnavailableError, DuplicateItemError, ExportConflictError, ExportNotFoundError, GlobalTableAlreadyExistsError, GlobalTableNotFoundError, IdempotentParameterMismatchError, ImportConflictError, ImportNotFoundError, IndexNotFoundError, InternalServerError, InvalidEndpointError, InvalidExportTimeError, InvalidRestoreTimeError, ItemCollectionSizeLimitExceededError, LimitExceededError, PointInTimeRecoveryUnavailableError, PolicyNotFoundError, ProvisionedThroughputExceededError, ReplicaAlreadyExistsError, ReplicaNotFoundError, RequestLimitExceededError, ResourceInUseError, ResourceNotFoundError, TableAlreadyExistsError, TableInUseError, TableNotFoundError, TransactionCanceledError, TransactionConflictError, TransactionInProgressError, SdkError } from "./Errors";
interface DynamoDBService$ {
    readonly _: unique symbol;
    /**
     * @see {@link BatchExecuteStatementCommand}
     */
    batchExecuteStatement(args: BatchExecuteStatementCommandInput, options?: __HttpHandlerOptions): Effect.Effect<BatchExecuteStatementCommandOutput, SdkError | InternalServerError | RequestLimitExceededError>;
    /**
     * @see {@link BatchGetItemCommand}
     */
    batchGetItem(args: BatchGetItemCommandInput, options?: __HttpHandlerOptions): Effect.Effect<BatchGetItemCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link BatchWriteItemCommand}
     */
    batchWriteItem(args: BatchWriteItemCommandInput, options?: __HttpHandlerOptions): Effect.Effect<BatchWriteItemCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link CreateBackupCommand}
     */
    createBackup(args: CreateBackupCommandInput, options?: __HttpHandlerOptions): Effect.Effect<CreateBackupCommandOutput, SdkError | BackupInUseError | ContinuousBackupsUnavailableError | InternalServerError | InvalidEndpointError | LimitExceededError | TableInUseError | TableNotFoundError>;
    /**
     * @see {@link CreateGlobalTableCommand}
     */
    createGlobalTable(args: CreateGlobalTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<CreateGlobalTableCommandOutput, SdkError | GlobalTableAlreadyExistsError | InternalServerError | InvalidEndpointError | LimitExceededError | TableNotFoundError>;
    /**
     * @see {@link CreateTableCommand}
     */
    createTable(args: CreateTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<CreateTableCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError>;
    /**
     * @see {@link DeleteBackupCommand}
     */
    deleteBackup(args: DeleteBackupCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DeleteBackupCommandOutput, SdkError | BackupInUseError | BackupNotFoundError | InternalServerError | InvalidEndpointError | LimitExceededError>;
    /**
     * @see {@link DeleteItemCommand}
     */
    deleteItem(args: DeleteItemCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DeleteItemCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link DeleteResourcePolicyCommand}
     */
    deleteResourcePolicy(args: DeleteResourcePolicyCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DeleteResourcePolicyCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | PolicyNotFoundError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link DeleteTableCommand}
     */
    deleteTable(args: DeleteTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DeleteTableCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link DescribeBackupCommand}
     */
    describeBackup(args: DescribeBackupCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeBackupCommandOutput, SdkError | BackupNotFoundError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link DescribeContinuousBackupsCommand}
     */
    describeContinuousBackups(args: DescribeContinuousBackupsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeContinuousBackupsCommandOutput, SdkError | InternalServerError | InvalidEndpointError | TableNotFoundError>;
    /**
     * @see {@link DescribeContributorInsightsCommand}
     */
    describeContributorInsights(args: DescribeContributorInsightsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeContributorInsightsCommandOutput, SdkError | InternalServerError | ResourceNotFoundError>;
    /**
     * @see {@link DescribeEndpointsCommand}
     */
    describeEndpoints(args: DescribeEndpointsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeEndpointsCommandOutput, SdkError>;
    /**
     * @see {@link DescribeExportCommand}
     */
    describeExport(args: DescribeExportCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeExportCommandOutput, SdkError | ExportNotFoundError | InternalServerError | LimitExceededError>;
    /**
     * @see {@link DescribeGlobalTableCommand}
     */
    describeGlobalTable(args: DescribeGlobalTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeGlobalTableCommandOutput, SdkError | GlobalTableNotFoundError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link DescribeGlobalTableSettingsCommand}
     */
    describeGlobalTableSettings(args: DescribeGlobalTableSettingsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeGlobalTableSettingsCommandOutput, SdkError | GlobalTableNotFoundError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link DescribeImportCommand}
     */
    describeImport(args: DescribeImportCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeImportCommandOutput, SdkError | ImportNotFoundError>;
    /**
     * @see {@link DescribeKinesisStreamingDestinationCommand}
     */
    describeKinesisStreamingDestination(args: DescribeKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeKinesisStreamingDestinationCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ResourceNotFoundError>;
    /**
     * @see {@link DescribeLimitsCommand}
     */
    describeLimits(args: DescribeLimitsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeLimitsCommandOutput, SdkError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link DescribeTableCommand}
     */
    describeTable(args: DescribeTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeTableCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ResourceNotFoundError>;
    /**
     * @see {@link DescribeTableReplicaAutoScalingCommand}
     */
    describeTableReplicaAutoScaling(args: DescribeTableReplicaAutoScalingCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeTableReplicaAutoScalingCommandOutput, SdkError | InternalServerError | ResourceNotFoundError>;
    /**
     * @see {@link DescribeTimeToLiveCommand}
     */
    describeTimeToLive(args: DescribeTimeToLiveCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DescribeTimeToLiveCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ResourceNotFoundError>;
    /**
     * @see {@link DisableKinesisStreamingDestinationCommand}
     */
    disableKinesisStreamingDestination(args: DisableKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DisableKinesisStreamingDestinationCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link EnableKinesisStreamingDestinationCommand}
     */
    enableKinesisStreamingDestination(args: EnableKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions): Effect.Effect<EnableKinesisStreamingDestinationCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link ExecuteStatementCommand}
     */
    executeStatement(args: ExecuteStatementCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ExecuteStatementCommandOutput, SdkError | ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteTransactionCommand}
     */
    executeTransaction(args: ExecuteTransactionCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ExecuteTransactionCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link ExportTableToPointInTimeCommand}
     */
    exportTableToPointInTime(args: ExportTableToPointInTimeCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ExportTableToPointInTimeCommandOutput, SdkError | ExportConflictError | InternalServerError | InvalidExportTimeError | LimitExceededError | PointInTimeRecoveryUnavailableError | TableNotFoundError>;
    /**
     * @see {@link GetItemCommand}
     */
    getItem(args: GetItemCommandInput, options?: __HttpHandlerOptions): Effect.Effect<GetItemCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link GetResourcePolicyCommand}
     */
    getResourcePolicy(args: GetResourcePolicyCommandInput, options?: __HttpHandlerOptions): Effect.Effect<GetResourcePolicyCommandOutput, SdkError | InternalServerError | InvalidEndpointError | PolicyNotFoundError | ResourceNotFoundError>;
    /**
     * @see {@link ImportTableCommand}
     */
    importTable(args: ImportTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ImportTableCommandOutput, SdkError | ImportConflictError | LimitExceededError | ResourceInUseError>;
    /**
     * @see {@link ListBackupsCommand}
     */
    listBackups(args: ListBackupsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListBackupsCommandOutput, SdkError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link ListContributorInsightsCommand}
     */
    listContributorInsights(args: ListContributorInsightsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListContributorInsightsCommandOutput, SdkError | InternalServerError | ResourceNotFoundError>;
    /**
     * @see {@link ListExportsCommand}
     */
    listExports(args: ListExportsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListExportsCommandOutput, SdkError | InternalServerError | LimitExceededError>;
    /**
     * @see {@link ListGlobalTablesCommand}
     */
    listGlobalTables(args: ListGlobalTablesCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListGlobalTablesCommandOutput, SdkError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link ListImportsCommand}
     */
    listImports(args: ListImportsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListImportsCommandOutput, SdkError | LimitExceededError>;
    /**
     * @see {@link ListTablesCommand}
     */
    listTables(args: ListTablesCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListTablesCommandOutput, SdkError | InternalServerError | InvalidEndpointError>;
    /**
     * @see {@link ListTagsOfResourceCommand}
     */
    listTagsOfResource(args: ListTagsOfResourceCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ListTagsOfResourceCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ResourceNotFoundError>;
    /**
     * @see {@link PutItemCommand}
     */
    putItem(args: PutItemCommandInput, options?: __HttpHandlerOptions): Effect.Effect<PutItemCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link PutResourcePolicyCommand}
     */
    putResourcePolicy(args: PutResourcePolicyCommandInput, options?: __HttpHandlerOptions): Effect.Effect<PutResourcePolicyCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | PolicyNotFoundError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link QueryCommand}
     */
    query(args: QueryCommandInput, options?: __HttpHandlerOptions): Effect.Effect<QueryCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link RestoreTableFromBackupCommand}
     */
    restoreTableFromBackup(args: RestoreTableFromBackupCommandInput, options?: __HttpHandlerOptions): Effect.Effect<RestoreTableFromBackupCommandOutput, SdkError | BackupInUseError | BackupNotFoundError | InternalServerError | InvalidEndpointError | LimitExceededError | TableAlreadyExistsError | TableInUseError>;
    /**
     * @see {@link RestoreTableToPointInTimeCommand}
     */
    restoreTableToPointInTime(args: RestoreTableToPointInTimeCommandInput, options?: __HttpHandlerOptions): Effect.Effect<RestoreTableToPointInTimeCommandOutput, SdkError | InternalServerError | InvalidEndpointError | InvalidRestoreTimeError | LimitExceededError | PointInTimeRecoveryUnavailableError | TableAlreadyExistsError | TableInUseError | TableNotFoundError>;
    /**
     * @see {@link ScanCommand}
     */
    scan(args: ScanCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ScanCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link TagResourceCommand}
     */
    tagResource(args: TagResourceCommandInput, options?: __HttpHandlerOptions): Effect.Effect<TagResourceCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link TransactGetItemsCommand}
     */
    transactGetItems(args: TransactGetItemsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<TransactGetItemsCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError>;
    /**
     * @see {@link TransactWriteItemsCommand}
     */
    transactWriteItems(args: TransactWriteItemsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<TransactWriteItemsCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link UntagResourceCommand}
     */
    untagResource(args: UntagResourceCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UntagResourceCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link UpdateContinuousBackupsCommand}
     */
    updateContinuousBackups(args: UpdateContinuousBackupsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateContinuousBackupsCommandOutput, SdkError | ContinuousBackupsUnavailableError | InternalServerError | InvalidEndpointError | TableNotFoundError>;
    /**
     * @see {@link UpdateContributorInsightsCommand}
     */
    updateContributorInsights(args: UpdateContributorInsightsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateContributorInsightsCommandOutput, SdkError | InternalServerError | ResourceNotFoundError>;
    /**
     * @see {@link UpdateGlobalTableCommand}
     */
    updateGlobalTable(args: UpdateGlobalTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateGlobalTableCommandOutput, SdkError | GlobalTableNotFoundError | InternalServerError | InvalidEndpointError | ReplicaAlreadyExistsError | ReplicaNotFoundError | TableNotFoundError>;
    /**
     * @see {@link UpdateGlobalTableSettingsCommand}
     */
    updateGlobalTableSettings(args: UpdateGlobalTableSettingsCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateGlobalTableSettingsCommandOutput, SdkError | GlobalTableNotFoundError | IndexNotFoundError | InternalServerError | InvalidEndpointError | LimitExceededError | ReplicaNotFoundError | ResourceInUseError>;
    /**
     * @see {@link UpdateItemCommand}
     */
    updateItem(args: UpdateItemCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateItemCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link UpdateKinesisStreamingDestinationCommand}
     */
    updateKinesisStreamingDestination(args: UpdateKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateKinesisStreamingDestinationCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link UpdateTableCommand}
     */
    updateTable(args: UpdateTableCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateTableCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link UpdateTableReplicaAutoScalingCommand}
     */
    updateTableReplicaAutoScaling(args: UpdateTableReplicaAutoScalingCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateTableReplicaAutoScalingCommandOutput, SdkError | InternalServerError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link UpdateTimeToLiveCommand}
     */
    updateTimeToLive(args: UpdateTimeToLiveCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateTimeToLiveCommandOutput, SdkError | InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
}
declare const DynamoDBService_base: import("effect/Context").TagClass<DynamoDBService, "@effect-aws/client-dynamodb/DynamoDBService", DynamoDBService$> & {
    readonly _: Effect.Effect<DynamoDBService$["_"], never, DynamoDBService>;
    batchExecuteStatement: (args: BatchExecuteStatementCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<BatchExecuteStatementCommandOutput, InternalServerError | RequestLimitExceededError | SdkError, DynamoDBService>;
    batchGetItem: (args: BatchGetItemCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<BatchGetItemCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBService>;
    batchWriteItem: (args: BatchWriteItemCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<BatchWriteItemCommandOutput, InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBService>;
    createBackup: (args: CreateBackupCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<CreateBackupCommandOutput, BackupInUseError | ContinuousBackupsUnavailableError | InternalServerError | InvalidEndpointError | LimitExceededError | TableInUseError | TableNotFoundError | SdkError, DynamoDBService>;
    createGlobalTable: (args: CreateGlobalTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<CreateGlobalTableCommandOutput, GlobalTableAlreadyExistsError | InternalServerError | InvalidEndpointError | LimitExceededError | TableNotFoundError | SdkError, DynamoDBService>;
    createTable: (args: CreateTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<CreateTableCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | SdkError, DynamoDBService>;
    deleteBackup: (args: DeleteBackupCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DeleteBackupCommandOutput, BackupInUseError | BackupNotFoundError | InternalServerError | InvalidEndpointError | LimitExceededError | SdkError, DynamoDBService>;
    deleteItem: (args: DeleteItemCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DeleteItemCommandOutput, ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBService>;
    deleteResourcePolicy: (args: DeleteResourcePolicyCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DeleteResourcePolicyCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | PolicyNotFoundError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    deleteTable: (args: DeleteTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DeleteTableCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    describeBackup: (args: DescribeBackupCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeBackupCommandOutput, BackupNotFoundError | InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    describeContinuousBackups: (args: DescribeContinuousBackupsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeContinuousBackupsCommandOutput, InternalServerError | InvalidEndpointError | TableNotFoundError | SdkError, DynamoDBService>;
    describeContributorInsights: (args: DescribeContributorInsightsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeContributorInsightsCommandOutput, InternalServerError | ResourceNotFoundError | SdkError, DynamoDBService>;
    describeEndpoints: (args: DescribeEndpointsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeEndpointsCommandOutput, SdkError, DynamoDBService>;
    describeExport: (args: DescribeExportCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeExportCommandOutput, ExportNotFoundError | InternalServerError | LimitExceededError | SdkError, DynamoDBService>;
    describeGlobalTable: (args: DescribeGlobalTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeGlobalTableCommandOutput, GlobalTableNotFoundError | InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    describeGlobalTableSettings: (args: DescribeGlobalTableSettingsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeGlobalTableSettingsCommandOutput, GlobalTableNotFoundError | InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    describeImport: (args: DescribeImportCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeImportCommandOutput, ImportNotFoundError | SdkError, DynamoDBService>;
    describeKinesisStreamingDestination: (args: DescribeKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeKinesisStreamingDestinationCommandOutput, InternalServerError | InvalidEndpointError | ResourceNotFoundError | SdkError, DynamoDBService>;
    describeLimits: (args: DescribeLimitsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeLimitsCommandOutput, InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    describeTable: (args: DescribeTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeTableCommandOutput, InternalServerError | InvalidEndpointError | ResourceNotFoundError | SdkError, DynamoDBService>;
    describeTableReplicaAutoScaling: (args: DescribeTableReplicaAutoScalingCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeTableReplicaAutoScalingCommandOutput, InternalServerError | ResourceNotFoundError | SdkError, DynamoDBService>;
    describeTimeToLive: (args: DescribeTimeToLiveCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DescribeTimeToLiveCommandOutput, InternalServerError | InvalidEndpointError | ResourceNotFoundError | SdkError, DynamoDBService>;
    disableKinesisStreamingDestination: (args: DisableKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<DisableKinesisStreamingDestinationCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    enableKinesisStreamingDestination: (args: EnableKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<EnableKinesisStreamingDestinationCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    executeStatement: (args: ExecuteStatementCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ExecuteStatementCommandOutput, ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBService>;
    executeTransaction: (args: ExecuteTransactionCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ExecuteTransactionCommandOutput, IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError | SdkError, DynamoDBService>;
    exportTableToPointInTime: (args: ExportTableToPointInTimeCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ExportTableToPointInTimeCommandOutput, ExportConflictError | InternalServerError | InvalidExportTimeError | LimitExceededError | PointInTimeRecoveryUnavailableError | TableNotFoundError | SdkError, DynamoDBService>;
    getItem: (args: GetItemCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<GetItemCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBService>;
    getResourcePolicy: (args: GetResourcePolicyCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<GetResourcePolicyCommandOutput, InternalServerError | InvalidEndpointError | PolicyNotFoundError | ResourceNotFoundError | SdkError, DynamoDBService>;
    importTable: (args: ImportTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ImportTableCommandOutput, ImportConflictError | LimitExceededError | ResourceInUseError | SdkError, DynamoDBService>;
    listBackups: (args: ListBackupsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListBackupsCommandOutput, InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    listContributorInsights: (args: ListContributorInsightsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListContributorInsightsCommandOutput, InternalServerError | ResourceNotFoundError | SdkError, DynamoDBService>;
    listExports: (args: ListExportsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListExportsCommandOutput, InternalServerError | LimitExceededError | SdkError, DynamoDBService>;
    listGlobalTables: (args: ListGlobalTablesCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListGlobalTablesCommandOutput, InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    listImports: (args: ListImportsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListImportsCommandOutput, LimitExceededError | SdkError, DynamoDBService>;
    listTables: (args: ListTablesCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListTablesCommandOutput, InternalServerError | InvalidEndpointError | SdkError, DynamoDBService>;
    listTagsOfResource: (args: ListTagsOfResourceCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ListTagsOfResourceCommandOutput, InternalServerError | InvalidEndpointError | ResourceNotFoundError | SdkError, DynamoDBService>;
    putItem: (args: PutItemCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<PutItemCommandOutput, ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBService>;
    putResourcePolicy: (args: PutResourcePolicyCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<PutResourcePolicyCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | PolicyNotFoundError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    query: (args: QueryCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<QueryCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBService>;
    restoreTableFromBackup: (args: RestoreTableFromBackupCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<RestoreTableFromBackupCommandOutput, BackupInUseError | BackupNotFoundError | InternalServerError | InvalidEndpointError | LimitExceededError | TableAlreadyExistsError | TableInUseError | SdkError, DynamoDBService>;
    restoreTableToPointInTime: (args: RestoreTableToPointInTimeCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<RestoreTableToPointInTimeCommandOutput, InternalServerError | InvalidEndpointError | InvalidRestoreTimeError | LimitExceededError | PointInTimeRecoveryUnavailableError | TableAlreadyExistsError | TableInUseError | TableNotFoundError | SdkError, DynamoDBService>;
    scan: (args: ScanCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<ScanCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBService>;
    tagResource: (args: TagResourceCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<TagResourceCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    transactGetItems: (args: TransactGetItemsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<TransactGetItemsCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | SdkError, DynamoDBService>;
    transactWriteItems: (args: TransactWriteItemsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<TransactWriteItemsCommandOutput, IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError | SdkError, DynamoDBService>;
    untagResource: (args: UntagResourceCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UntagResourceCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    updateContinuousBackups: (args: UpdateContinuousBackupsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateContinuousBackupsCommandOutput, ContinuousBackupsUnavailableError | InternalServerError | InvalidEndpointError | TableNotFoundError | SdkError, DynamoDBService>;
    updateContributorInsights: (args: UpdateContributorInsightsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateContributorInsightsCommandOutput, InternalServerError | ResourceNotFoundError | SdkError, DynamoDBService>;
    updateGlobalTable: (args: UpdateGlobalTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateGlobalTableCommandOutput, GlobalTableNotFoundError | InternalServerError | InvalidEndpointError | ReplicaAlreadyExistsError | ReplicaNotFoundError | TableNotFoundError | SdkError, DynamoDBService>;
    updateGlobalTableSettings: (args: UpdateGlobalTableSettingsCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateGlobalTableSettingsCommandOutput, GlobalTableNotFoundError | IndexNotFoundError | InternalServerError | InvalidEndpointError | LimitExceededError | ReplicaNotFoundError | ResourceInUseError | SdkError, DynamoDBService>;
    updateItem: (args: UpdateItemCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateItemCommandOutput, ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBService>;
    updateKinesisStreamingDestination: (args: UpdateKinesisStreamingDestinationCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateKinesisStreamingDestinationCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    updateTable: (args: UpdateTableCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateTableCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    updateTableReplicaAutoScaling: (args: UpdateTableReplicaAutoScalingCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateTableReplicaAutoScalingCommandOutput, InternalServerError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
    updateTimeToLive: (args: UpdateTimeToLiveCommandInput, options?: __HttpHandlerOptions | undefined) => Effect.Effect<UpdateTimeToLiveCommandOutput, InternalServerError | InvalidEndpointError | LimitExceededError | ResourceInUseError | ResourceNotFoundError | SdkError, DynamoDBService>;
} & {
    use: <X>(body: (_: DynamoDBService$) => X) => X extends Effect.Effect<infer A, infer E, infer R> ? Effect.Effect<A, E, R | DynamoDBService> : Effect.Effect<X, never, DynamoDBService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class DynamoDBService extends DynamoDBService_base {
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeDynamoDBService: Effect.Effect<DynamoDBService$, never, DynamoDBClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const BaseDynamoDBServiceLayer: Layer.Layer<DynamoDBService, never, DynamoDBClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DynamoDBServiceLayer: Layer.Layer<DynamoDBService, never, import("./DynamoDBClientInstanceConfig").DynamoDBClientInstanceConfig>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DefaultDynamoDBServiceLayer: Layer.Layer<DynamoDBService, never, never>;
export {};
